==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Non se atoparon calendarios.",
"No events found." => "Non se atoparon eventos.",
"Wrong calendar" => "Calendario equivocado",
"New Timezone:" => "Novo fuso horario:",
"Timezone changed" => "Fuso horario trocado",
"Invalid request" => "Petición non válida",
"Calendar" => "Calendario",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d MMM[ yyyy]{ '&#8212;'d [ MMM] yyyy}",
"Birthday" => "Aniversario",
"Business" => "Traballo",
"Call" => "Chamada",
"Clients" => "Clientes",
"Deliverer" => "Remitente",
"Holidays" => "Vacacións",
"Ideas" => "Ideas",
"Journey" => "Viaxe",
"Jubilee" => "Aniversario especial",
"Meeting" => "Reunión",
"Other" => "Outro",
"Personal" => "Persoal",
"Projects" => "Proxectos",
"Questions" => "Preguntas",
"Work" => "Traballo",
"unnamed" => "sen nome",
"Does not repeat" => "Non se repite",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Every Weekday" => "Todas as semanas",
"Bi-Weekly" => "Cada dúas semanas",
"Monthly" => "Mensual",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por acontecementos",
"by date" => "por data",
"by monthday" => "por día do mes",
"by weekday" => "por día da semana",
"Monday" => "Luns",
"Tuesday" => "Martes",
"Wednesday" => "Mércores",
"Thursday" => "Xoves",
"Friday" => "Venres",
"Saturday" => "Sábado",
"Sunday" => "Domingo",
"events week of month" => "semana dos eventos no mes",
"first" => "primeiro",
"second" => "segundo",
"third" => "terceiro",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"January" => "Xaneiro",
"February" => "Febreiro",
"March" => "Marzo",
"April" => "Abril",
"May" => "Maio",
"June" => "Xuño",
"July" => "Xullo",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Decembro",
"by events date" => "por data dos eventos",
"by yearday(s)" => "por dia(s) do ano",
"by weeknumber(s)" => "por número(s) de semana",
"by day and month" => "por día e mes",
"Date" => "Data",
"Cal." => "Cal.",
"All day" => "Todo o dia",
"New Calendar" => "Novo calendario",
"Missing fields" => "Faltan campos",
"Title" => "Título",
"From Date" => "Desde a data",
"From Time" => "Desde a hora",
"To Date" => "á data",
"To Time" => "á hora",
"The event ends before it starts" => "O evento remata antes de iniciarse",
"There was a database fail" => "Produciuse un erro na base de datos",
"Week" => "Semana",
"Month" => "Mes",
"List" => "Lista",
"Today" => "Hoxe",
"Calendars" => "Calendarios",
"There was a fail, while parsing the file." => "Produciuse un erro ao procesar o ficheiro",
"Choose active calendars" => "Escolla os calendarios activos",
"Your calendars" => "Os seus calendarios",
"CalDav Link" => "Ligazón CalDav",
"Shared calendars" => "Calendarios compartidos",
"No shared calendars" => "Sen calendarios compartidos",
"Share Calendar" => "Compartir calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Borrar",
"shared with you by" => "compartido con vostede por",
"New calendar" => "Novo calendario",
"Edit calendar" => "Editar calendario",
"Displayname" => "Mostrar nome",
"Active" => "Activo",
"Calendar color" => "Cor do calendario",
"Save" => "Gardar",
"Submit" => "Enviar",
"Cancel" => "Cancelar",
"Edit an event" => "Editar un evento",
"Export" => "Exportar",
"Eventinfo" => "Info do evento",
"Repeating" => "Repetido",
"Alarm" => "Alarma",
"Attendees" => "Participantes",
"Share" => "Compartir",
"Title of the Event" => "Título do evento",
"Category" => "Categoría",
"Separate categories with commas" => "Separe as categorías con comas",
"Edit categories" => "Editar categorías",
"All Day Event" => "Eventos do día",
"From" => "Desde",
"To" => "a",
"Advanced options" => "Opcións avanzadas",
"Location" => "Localización",
"Location of the Event" => "Localización do evento",
"Description" => "Descrición",
"Description of the Event" => "Descrición do evento",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar días da semana",
"Select days" => "Seleccionar días",
"and the events day of year." => "e día dos eventos no ano.",
"and the events day of month." => "e día dos eventos no mes.",
"Select months" => "Seleccione meses",
"Select weeks" => "Seleccionar semanas",
"and the events week of year." => "e semana dos eventos no ano.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "acontecementos",
"Import a calendar file" => "Importar un ficheiro de calendario",
"Please choose the calendar" => "Por favor, seleccione o calendario",
"create a new calendar" => "crear un novo calendario",
"Name of new calendar" => "Nome do novo calendario",
"Import" => "Importar",
"Importing calendar" => "Importar calendario",
"Calendar imported successfully" => "Calendario importado correctamente",
"Close Dialog" => "Pechar diálogo",
"Create a new event" => "Crear un novo evento",
"View an event" => "Ver un evento",
"No categories selected" => "Non seleccionou as categorías",
"Select category" => "Seleccionar categoría",
"of" => "de",
"at" => "a",
"Timezone" => "Fuso horario",
"Check always for changes of the timezone" => "Comprobar sempre cambios de fuso horario",
"Timeformat" => "Formato de hora",
"24h" => "24h",
"12h" => "12h",
"First day of the week" => "Primeiro día da semana",
"Calendar CalDAV syncing address:" => "Enderezo de sincronización do calendario CalDAV:",
"Users" => "Usuarios",
"select users" => "escoller usuarios",
"Editable" => "Editable",
"Groups" => "Grupos",
"select groups" => "escoller grupos",
"make public" => "facer público"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Non se atoparon calendarios.",
"No events found." => "Non se atoparon eventos.",
"Wrong calendar" => "Calendario equivocado",
"New Timezone:" => "Novo fuso horario:",
"Timezone changed" => "Fuso horario trocado",
"Invalid request" => "Petición non válida",
"Calendar" => "Calendario",
"Editable" => "Editable",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d MMM[ yyyy]{ '&#8212;'d [ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d,yyyy",
"Birthday" => "Aniversario",
"Business" => "Traballo",
"Call" => "Chamada",
"Clients" => "Clientes",
"Deliverer" => "Remitente",
"Holidays" => "Vacacións",
"Ideas" => "Ideas",
"Journey" => "Viaxe",
"Jubilee" => "Aniversario especial",
"Meeting" => "Reunión",
"Other" => "Outro",
"Personal" => "Persoal",
"Projects" => "Proxectos",
"Questions" => "Preguntas",
"Work" => "Traballo",
"unnamed" => "sen nome",
"New Calendar" => "Novo calendario",
"Does not repeat" => "Non se repite",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Every Weekday" => "Todas as semanas",
"Bi-Weekly" => "Cada dúas semanas",
"Monthly" => "Mensual",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por acontecementos",
"by date" => "por data",
"by monthday" => "por día do mes",
"by weekday" => "por día da semana",
"Monday" => "Luns",
"Tuesday" => "Martes",
"Wednesday" => "Mércores",
"Thursday" => "Xoves",
"Friday" => "Venres",
"Saturday" => "Sábado",
"Sunday" => "Domingo",
"events week of month" => "semana dos eventos no mes",
"first" => "primeiro",
"second" => "segundo",
"third" => "terceiro",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"January" => "Xaneiro",
"February" => "Febreiro",
"March" => "Marzo",
"April" => "Abril",
"May" => "Maio",
"June" => "Xuño",
"July" => "Xullo",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Decembro",
"by events date" => "por data dos eventos",
"by yearday(s)" => "por dia(s) do ano",
"by weeknumber(s)" => "por número(s) de semana",
"by day and month" => "por día e mes",
"Date" => "Data",
"Cal." => "Cal.",
"All day" => "Todo o dia",
"Missing fields" => "Faltan campos",
"Title" => "Título",
"From Date" => "Desde a data",
"From Time" => "Desde a hora",
"To Date" => "á data",
"To Time" => "á hora",
"The event ends before it starts" => "O evento remata antes de iniciarse",
"There was a database fail" => "Produciuse un erro na base de datos",
"Week" => "Semana",
"Month" => "Mes",
"List" => "Lista",
"Today" => "Hoxe",
"Your calendars" => "Os seus calendarios",
"CalDav Link" => "Ligazón CalDav",
"Share Calendar" => "Compartir calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Borrar",
"shared with you by" => "compartido con vostede por",
"New calendar" => "Novo calendario",
"Edit calendar" => "Editar calendario",
"Displayname" => "Mostrar nome",
"Active" => "Activo",
"Calendar color" => "Cor do calendario",
"Save" => "Gardar",
"Submit" => "Enviar",
"Cancel" => "Cancelar",
"Edit an event" => "Editar un evento",
"Export" => "Exportar",
"Eventinfo" => "Info do evento",
"Repeating" => "Repetido",
"Alarm" => "Alarma",
"Attendees" => "Participantes",
"Share" => "Compartir",
"Title of the Event" => "Título do evento",
"Category" => "Categoría",
"Separate categories with commas" => "Separe as categorías con comas",
"Edit categories" => "Editar categorías",
"All Day Event" => "Eventos do día",
"From" => "Desde",
"To" => "a",
"Advanced options" => "Opcións avanzadas",
"Location" => "Localización",
"Location of the Event" => "Localización do evento",
"Description" => "Descrición",
"Description of the Event" => "Descrición do evento",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar días da semana",
"Select days" => "Seleccionar días",
"and the events day of year." => "e día dos eventos no ano.",
"and the events day of month." => "e día dos eventos no mes.",
"Select months" => "Seleccione meses",
"Select weeks" => "Seleccionar semanas",
"and the events week of year." => "e semana dos eventos no ano.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "acontecementos",
"create a new calendar" => "crear un novo calendario",
"Import a calendar file" => "Importar un ficheiro de calendario",
"Name of new calendar" => "Nome do novo calendario",
"Import" => "Importar",
"Close Dialog" => "Pechar diálogo",
"Create a new event" => "Crear un novo evento",
"View an event" => "Ver un evento",
"No categories selected" => "Non seleccionou as categorías",
"of" => "de",
"at" => "a",
"Timezone" => "Fuso horario",
"24h" => "24h",
"12h" => "12h"
);
